@@ -33,8 +33,8 @@ get_cpu_internal = function() {
     cmd  = "awk '/model name/' /proc/cpuinfo"
     model_name = gsub("model name\t: ", "", unique(system(cmd, intern = TRUE)))
   } else if (length(grep("^darwin", os))) {
-    sysctl = Sys.which("sysctl")
-    if (nchar(sysctl) == 0L) {
+    sysctl = get_sysctl()
+    if (is.na(sysctl)) {
       vendor_id = model_name = NA
     } else {
       vendor_id = system(paste(sysctl, "-n machdep.cpu.vendor"), intern = TRUE) # nocov
